==> rawlog-6.x-1.2.tar.gz: rawlog/rawlog.js <==
// $Id: rawlog.js,v 1.1.2.5 2010/04/19 18:15:52 vitoa Exp $
if (Drupal.jsEnabled) {
  $(document).ready(function(){
    var str;
    var filename;
    var m;

    $("#edit-rawlog-place-to-files").click(function() {
      if ($("#edit-rawlog-place-to-files").is(":checked")) {
        str = $("#edit-rawlog-filename").val();
        m = str.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/);
        filename = m[2];
        $("#edit-rawlog-filename").val(files_folder + filename);
      }
    });
    
    if ($("#edit-rawlog-enable-tags").size() && $("#edit-rawlog-enable-tags").attr("checked")) {
      // Enable input and show its description.
      $("#edit-rawlog-tags").removeAttr("disabled");
      $("#edit-rawlog-tags")[0].focus();
      $("#edit-rawlog-tags-wrapper > div[class=description]").slideDown('fast');
    }
    $("#edit-rawlog-enable-tags").bind("click", function() {
      if ($("#edit-rawlog-enable-tags").attr("checked")) {
        // Enable tags checked; enable input.
        $("#edit-rawlog-tags").removeAttr("disabled");
        $("#edit-rawlog-tags")[0].focus();
        $("#edit-rawlog-tags-wrapper > div[class=description]").slideDown('fast');
      }
      else {
        // Enable tags unchecked; disable input.
        $("#edit-rawlog-tags").attr("disabled","disabled");
        $("#edit-rawlog-tags-wrapper > div[class=description]").slideUp('fast');
      }
    });

    /* tab panels mouse hovering */
    var rotations = [
      "#edit-rawlog-logs-rotation-hour",
      "#edit-rawlog-logs-rotation-day",
      "#edit-rawlog-logs-rotation-week",
      "#edit-rawlog-logs-rotation-month"
    ];

    jQuery.each(rotations, function(i, val) {
      if ($.browser.msie) {
        $(val).click(function() {
          this.blur();
          this.focus();
        });
      }
      $(val).change(function() {
        if($(this).is(':checked'))  {
          str = $("#edit-rawlog-filename").val();
          if (str.search('@date') < 0) {
            m = str.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/);
            filename = m[2];
            str = str.replace(filename, '@date' + filename);
            $("#edit-rawlog-filename").val(str);
          }
        }
      });
    });
  });
}

==> rawlog-6.x-1.4.tar.gz: rawlog/rawlog.js <==
// $Id: rawlog.js,v 1.1.2.6 2010/06/08 23:19:36 vitoa Exp $
if (Drupal.jsEnabled) {
  $(document).ready(function(){
    var str;
    var filename;
    var m;

    $("#edit-rawlog-place-to-files").click(function() {
      if ($("#edit-rawlog-place-to-files").is(":checked")) {
        str = $("#edit-rawlog-filename").val();
        m = str.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/);
        filename = m[2];
        $("#edit-rawlog-filename").val(files_folder + filename);
      }
    });
    
    if ($("#edit-rawlog-enable-tags").size() && $("#edit-rawlog-enable-tags").attr("checked")) {
      // Enable tags input and show its description.
      $("#edit-rawlog-tags").removeAttr("disabled");
      $("#edit-rawlog-tags")[0].focus();
      $("#edit-rawlog-tags-wrapper > div[class=description]").slideDown('fast');
      // Enable negative tags input and show its description.
      $("#edit-rawlog-negative-tags").removeAttr("disabled");
      $("#edit-rawlog-negative-tags")[0].focus();
      $("#edit-rawlog-negative-tags-wrapper > div[class=description]").slideDown('fast');
    }
    $("#edit-rawlog-enable-tags").bind("click", function() {
      if ($("#edit-rawlog-enable-tags").attr("checked")) {
        // Enable tags checked; enable input.
        $("#edit-rawlog-tags").removeAttr("disabled");
        $("#edit-rawlog-tags")[0].focus();
        $("#edit-rawlog-tags-wrapper > div[class=description]").slideDown('fast');
        // Enable negative tags input and show its description.
        $("#edit-rawlog-negative-tags").removeAttr("disabled");
        $("#edit-rawlog-negative-tags")[0].focus();
        $("#edit-rawlog-negative-tags-wrapper > div[class=description]").slideDown('fast');
      }
      else {
        // Enable tags unchecked; disable input.
        $("#edit-rawlog-tags").attr("disabled","disabled");
        $("#edit-rawlog-tags-wrapper > div[class=description]").slideUp('fast');
        // Enable tags unchecked; disable input.
        $("#edit-rawlog-negative-tags").attr("disabled","disabled");
        $("#edit-rawlog-negative-tags-wrapper > div[class=description]").slideUp('fast');
      }
    });

    /* tab panels mouse hovering */
    var rotations = [
      "#edit-rawlog-logs-rotation-hour",
      "#edit-rawlog-logs-rotation-day",
      "#edit-rawlog-logs-rotation-week",
      "#edit-rawlog-logs-rotation-month"
    ];

    jQuery.each(rotations, function(i, val) {
      if ($.browser.msie) {
        $(val).click(function() {
          this.blur();
          this.focus();
        });
      }
      $(val).change(function() {
        if($(this).is(':checked'))  {
          str = $("#edit-rawlog-filename").val();
          if (str.search('@date') < 0) {
            m = str.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/);
            filename = m[2];
            str = str.replace(filename, '@date' + filename);
            $("#edit-rawlog-filename").val(str);
          }
        }
      });
    });
  });
}
